@@ -278,7 +278,7 @@ COPY_XQ2(DocumentOrder, Expression, Unordered)
 COPY_XQ3(Predicate, Expression, Predicate, Reverse)
 COPY_XQ1(NameExpression, Expression)
 COPY_XQ1(ContentSequence, Expression)
-COPY_XQ2(DirectName, QName, IsAttr)
+COPY_XQ2(DirectName, QName, UseDefaultNamespace)
 COPY_XQ2(NamespaceBinding, Namespaces, Expression)
 COPY_XQ2(FunctionConversion, Expression, SequenceType)
 COPY_XQ5(AnalyzeString, Expression, Regex, Flags, Match, NonMatch)
